@@ -47,6 +47,7 @@
 #include <QQmlContext>
 #include <QGraphicsOpacityEffect>
 #include <QLabel>
+#include <QMenu>
 #include <QDebug>
 
 #include <KActivities/Stats/ResultModel>
@@ -233,6 +234,7 @@ public:
 
     ToolTipManager *toolTipManager = nullptr;
     ToolTipManager *subCategoryToolTipManager = nullptr;
+    ToolTipManager *mostUsedToolTipManager = nullptr;
     QQuickWidget * quickWidget = nullptr;
     KPackage::Package package;
     SubcategoryModel * subCategoryModel = nullptr;
@@ -249,6 +251,15 @@ public:
     QPersistentModelIndex activeCategoryIndex;
     int activeCategory;
     int activeSubCategory;
+    bool m_actionMenuVisible = false;
+    void setActionMenuVisible(SidebarMode* sidebarMode, const bool &actionMenuVisible)
+    {
+        if (m_actionMenuVisible == actionMenuVisible) {
+            return;
+        }
+        m_actionMenuVisible = actionMenuVisible;
+        emit sidebarMode->actionMenuVisibleChanged();
+    }
 };
 
 SidebarMode::SidebarMode( QObject *parent, const QVariantList& )
@@ -379,6 +390,13 @@ void SidebarMode::requestSubCategoryToolTip(int index, const QRectF &rect)
     }
 }
 
+void SidebarMode::requestMostUsedToolTip(int index, const QRectF &rect)
+{
+    if (showToolTips()) {
+        d->mostUsedToolTipManager->requestToolTip(d->mostUsedModel->index(index, 0), rect.toRect());
+    }
+}
+
 void SidebarMode::hideToolTip()
 {
     d->toolTipManager->hideToolTip();
@@ -389,6 +407,11 @@ void SidebarMode::hideSubCategoryToolTip()
     d->subCategoryToolTipManager->hideToolTip();
 }
 
+void SidebarMode::hideMostUsedToolTip()
+{
+    d->mostUsedToolTipManager->hideToolTip();
+}
+
 void SidebarMode::loadMostUsed(int index)
 {
     const QModelIndex idx = d->mostUsedModel->index(index, 0);
@@ -396,6 +419,21 @@ void SidebarMode::loadMostUsed(int index)
     d->moduleView->loadModule( idx );
 }
 
+void SidebarMode::showActionMenu(const QPoint &position)
+{
+    QMenu *menu = new QMenu();
+    connect(menu, &QMenu::aboutToHide, this, [this] () { d->setActionMenuVisible(this, false); } );
+    menu->setAttribute(Qt::WA_DeleteOnClose);
+
+    const QStringList actionList { QStringLiteral("configure"), QStringLiteral("help_contents"), QStringLiteral("help_about_app"), QStringLiteral("help_about_kde") };
+    for (const QString &actionName : actionList) {
+        menu->addAction(d->collection->action(actionName));
+    }
+
+    menu->popup(position);
+    d->setActionMenuVisible(this, true);
+}
+
 void SidebarMode::changeModule( const QModelIndex& activeModule )
 {
     d->moduleView->closeModules();
@@ -442,11 +480,6 @@ void SidebarMode::setActiveCategory(int cat)
     emit activeSubCategoryChanged();
 }
 
-int SidebarMode::activeSubCategory() const
-{
-    return d->activeSubCategory;
-}
-
 void SidebarMode::setActiveSubCategory(int cat)
 {
     if (d->activeSubCategory == cat) {
@@ -468,6 +501,16 @@ int SidebarMode::width() const
     return d->mainWidget->width();
 }
 
+bool SidebarMode::actionMenuVisible() const
+{
+    return d->m_actionMenuVisible;
+}
+
+int SidebarMode::activeSubCategory() const
+{
+    return d->activeSubCategory;
+}
+
 void SidebarMode::initWidget()
 {
     // Create the widgets
@@ -519,9 +562,6 @@ void SidebarMode::initWidget()
 
     d->quickWidget->installEventFilter(this);
 
-    d->toolTipManager = new ToolTipManager(d->searchModel, d->quickWidget);
-    d->subCategoryToolTipManager = new ToolTipManager(d->subCategoryModel, d->quickWidget);
-
     d->placeHolderWidget = new QQuickWidget(d->mainWidget);
     d->placeHolderWidget->quickWindow()->setTitle(i18n("Most Used"));
     d->placeHolderWidget->setResizeMode(QQuickWidget::SizeRootObjectToView);
@@ -538,6 +578,10 @@ void SidebarMode::initWidget()
     d->mainLayout->addWidget( d->placeHolderWidget );
     emit changeToolBarItems(BaseMode::NoItems);
 
+    d->toolTipManager = new ToolTipManager(d->searchModel, d->quickWidget, ToolTipManager::ToolTipPosition::Right);
+    d->subCategoryToolTipManager = new ToolTipManager(d->subCategoryModel, d->quickWidget, ToolTipManager::ToolTipPosition::Right);
+    d->mostUsedToolTipManager = new ToolTipManager(d->mostUsedModel, d->placeHolderWidget, ToolTipManager::ToolTipPosition::BottomCenter);
+
     d->mostUsedModel->setResultModel(new ResultModel( AllResources | Agent(QStringLiteral("org.kde.systemsettings")) | HighScoredFirst | Limit(5), this));
 }
 
